<?php

/**
 * Link Blink package for Concrete5
 * Copyright 2020, Alex Borisov. All Rights Reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @copyright 2018-2020, Alex Borisov. All Rights Reserved.
 * @package Concrete\Package\ab_link_blink
 */

namespace Concrete\Package\AbLinkBlink\Block\AbLinkBlink;

use Concrete\Core\Block\BlockController;
use Less_Parser;
use Less_Tree_Rule;
use Concrete\Core\Page\Page;
use Concrete\Core\Support\Facade\Url;

class Controller extends BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "600";
    protected $btTable = 'btAbLinkBlink';
    
    public function getBlockTypeDescription() 
    {
        return t("Add Link Blink block");
    }

    public function getBlockTypeName() 
    {
        return t("Link Blink");
    }

    public function registerViewAssets($outputContent = '')
    {
        $this->requireAsset('javascript', 'jquery');
        $this->requireAsset('css', 'font-awesome');
    }
    
    public function on_page_view() {
        $html = $this->app->make('helper/html');
        
        $style = '<style>';
        $style .= '#ab_link_blink_' . $this->bID . ' span.blink {';
        $style .= '-webkit-animation: color-change-' . $this->bID . ' 1s infinite;';
        $style .= '-moz-animation: color-change-' . $this->bID . ' 1s infinite;';
        $style .= '-o-animation: color-change-' . $this->bID . ' 1s infinite;';
        $style .= '-ms-animation: color-change-' . $this->bID . ' 1s infinite;';
        $style .= 'animation: color-change-' . $this->bID . ' 1s infinite;';
        $style .= '}';
        $style .= '@-webkit-keyframes color-change-' . $this->bID . ' {';
        $style .= '0% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '50% { color: ' . $this->link_blink_color . '; }';
        $style .= '100% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '}';
        $style .= '@-moz-keyframes color-change-' . $this->bID . ' {';
        $style .= '0% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '50% { color: ' . $this->link_blink_color . '; }';
        $style .= '100% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '}';
        $style .= '@-ms-keyframes color-change-' . $this->bID . ' {';
        $style .= '0% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '50% { color: ' . $this->link_blink_color . '; }';
        $style .= '100% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '}';
        $style .= '@-o-keyframes color-change-' . $this->bID . ' {';
        $style .= '0% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '50% { color: ' . $this->link_blink_color . '; }';
        $style .= '100% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '}';
        $style .= '@keyframes color-change-' . $this->bID . ' {';
        $style .= '0% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '50% { color: ' . $this->link_blink_color . '; }';
        $style .= '100% { color: ' . $this->link_no_blink_color . '; }';
        $style .= '}';
        $style .= '</style>';
        
        $this->addHeaderItem($style);
    }
    
    public function view()
    {
        $url = $this->goto_id ? '#' . $this->goto_id : '';
        if ($this->page_id > 0) {
            $page = Page::getByID($this->page_id);
            if (!$page->isError()) {
                $url = $page->getCollectionLink() . $url;
            }
        }
        else {
            $page = Page::getCurrentPage();
            if (!$page->isError()) {
                $url = $page->getCollectionLink() . $url;
            }
        }
        $this->set('url', Url::to($url));
    }
    
    public function add()
    {
        $this->edit();
    }
    
    public function edit()
    {
        $this->set('app', $this->app);
        
        $this->requireAsset('javascript', 'bootstrap/tooltip');
        $this->requireAsset('css', 'bootstrap/tooltip');
        
        $classes = $this->getSymbolClasses();
        $symbols = array('' => t('Choose Symbol'));
        $txt = $this->app->make('helper/text');
        foreach ($classes as $class) {
            $symbols[$class] = $txt->unhandle($class);
        }
        $this->set('symbols', $symbols);
        
        $this->set('link_no_blink_color', $this->link_no_blink_color ? $this->link_no_blink_color : '#0099ff');
        $this->set('link_blink_color', $this->link_blink_color ? $this->link_blink_color : '#ff4100');
    }
    
    protected function getSymbolClasses()
    {
        $symbol_less_file = DIR_BASE_CORE . '/css/build/vendor/font-awesome/variables.less';
        $symbols = array();

        $l = new Less_Parser();
        $parser = $l->parseFile($symbol_less_file, false, true);
        $rules = $parser->rules;

        foreach ($rules as $rule) {
            if ($rule instanceof Less_Tree_Rule) {
                if (strpos($rule->name, '@fa-var') === 0) {
                    $name = str_replace('@fa-var-', '', $rule->name);
                    $symbols[] = $name;
                }
            }
        }
        asort($symbols);

        return $symbols;
    }

    public function save($data)
    {
        $data['page_id'] = isset($data['page_id']) ? $data['page_id'] : 0;
        $data['goto_id'] = isset($data['goto_id']) ? $data['goto_id'] : '';
        $data['link_no_blink_string'] = isset($data['link_no_blink_string']) ? $data['link_no_blink_string'] : '';
        $data['link_blink_string'] = isset($data['link_blink_string']) ? $data['link_blink_string'] : '';
        $data['link_no_blink_color'] = isset($data['link_no_blink_color']) ? $data['link_no_blink_color'] : '#0099ff';
        $data['link_blink_color'] = isset($data['link_blink_color']) ? $data['link_blink_color'] : '#ff4100';
        $data['symbol'] = isset($data['symbol']) ? $data['symbol'] : '';
        parent::save($data);
    }
}
